@@ -1,4 +1,3 @@
-import os
 from pathlib import Path
 
 from django.conf import settings
@@ -11,7 +10,6 @@ from django_s3_csv_2_sfdc.s3_helpers import (
     timestamp_s3_key,
 )
 from django_s3_csv_2_sfdc.sfdc_helpers import parse_bulk_upsert_results
-from django_s3_csv_2_sfdc.utils import get_iso
 
 
 class SfClient(Salesforce):
@@ -27,7 +25,7 @@ class SfClient(Salesforce):
         super().__init__(**config)
 
 
-class DjangoS3Csv2Sfdc:
+class Orchestrator:
     """
     This class can be used to orchestrate the following flow
 
@@ -67,13 +65,16 @@ class DjangoS3Csv2Sfdc:
         self.execution_object_name = execution_object_name
 
         self.downloaded_file = s3_to_temp(s3_object_key, bucket_name)
-        self.sf_client = sf_client if sf_client else SfClient()
+        self.sf_client = sf_client
 
         self.error_report_path: str = None
         self.error_count: int = None
 
         self.batches = list()
 
+    def set_sf_client(self, sf_client: SfClient):
+        self.sf_client = sf_client
+
     def log_batch(
         self, results: list, data: list, salesforce_object: str, upsert_key: str
     ):
@@ -129,6 +130,7 @@ class DjangoS3Csv2Sfdc:
         return Path(error_folder) / error_report_s3_key
 
     def create_execution_object(self):
+        assert self.sf_client, f"sf_client isn't set"
         getattr(self.sf_client, self.execution_object_name).create(
             self.execution_sfdc_hash
         )
