@@ -1,10 +1,10 @@
 import boto3
 import os
 
-from django.conf import settings
-
 from pathlib import Path
 
+from django_s3_csv_2_sfdc.utils import get_temp, get_iso
+
 
 def upload_file(
     local_path: Path, bucket, s3_key: Path = None, public_read: bool = False
@@ -66,7 +66,7 @@ def s3_to_temp(s3_object_key, bucket_name) -> Path:
 
     TEMP must be defined in your django settings
     """
-    tmp = Path(settings.TEMP)
+    tmp = get_temp()
 
     s3_client = boto3.client("s3")
     download_folder = tmp / os.path.dirname(s3_object_key)
@@ -75,4 +75,19 @@ def s3_to_temp(s3_object_key, bucket_name) -> Path:
     Path(download_folder).mkdir(parents=True, exist_ok=True)
     s3_client.download_file(bucket_name, s3_object_key, str(download_path))
 
-    return download_path
\ No newline at end of file
+    return download_path
+
+
+def timestamp_s3_key(s3_key: str, keep_folder: bool = False) -> str:
+    dir_name = os.path.dirname(s3_key)
+    file_name = os.path.basename(s3_key)
+    name_and_extension = os.path.splitext(file_name)
+    assert len(name_and_extension) == 2
+    name = name_and_extension[0]
+    extension = name_and_extension[1]
+    iso = get_iso()
+
+    timestamped_s3_key = f"{name}-{iso}{extension}"
+    if keep_folder:
+        return os.path.join(dir_name, timestamped_s3_key)
+    return timestamped_s3_key
